;;;; Definition of Model Parameters ;;;;
globals [
  fox-carcap                        ;;;; to set the carrying capacity of the model fox habitat
  village-size                      ;;;; to set the area of each village
  dog-population                    ;;;; number of dogs in the model landscape
  inf-foxes                         ;;;;
  fox0                              ;;;; ini-foxpop
  final-foxpop
  ro
  cumscc
  cuminff
  d                                 ;;;; counter that resets every 365 days
  td                                ;;;; counter that resets every 30 days
  pre
  m
  s
  prosus
  prorec
  infdog0
  dog0
  CDVdogincrate
  CDVfoxincrate
  cdd
  cumsdc
  cumsdcf
  inffox0
  year
  famCDV                            ;;;; fox annual mortality due to CDV
  month
  infdog0m
  infdog0c
  yinfdog0
  yinffox0
  ycumsdc
  ycumsdcf
  CDVincratedog
  CDVincratefox
  spoeve
  probspo
  soe                               ;;;; spillover event
  ddd
]
breed [dogs dog]
breed [foxes fox]

dogs-own
[
  home-patch
  susceptible?
  infected?
  infectious?
  recovered?
  ip
  ddt
  iddt
  scc
  rd?
  sdc                               ;;;; susceptible-days-counter
  ]
foxes-own
[
  home-patch
  susceptible?
  infected?
  infectious?
  immune?
  scc                               ;;;; secondary case counter
  lid                               ;;;; counter for disease progression in foxes
  sdc                               ;;;; susceptible-days-counter
]
;
;
;

to setup
  clear-all
  setup-landscape
  reset-ticks
end

to setup-landscape
  set village-size 5
  ask (patch-set patch -14 14 patch -14 -14 patch 14 -14 patch 14 14) [
    ask n-of village-size patches in-radius 2 [
      set pcolor red
      ask patches in-radius 2 with [pcolor = black] [
        set pcolor brown + 1
      ]
    ]
    ask patches in-radius 9 with [pcolor = black] [
      if (random-float 100 < 21) [
        set pcolor green
      ]
    ]
  ]

  ask patches with [pcolor = red] [
    sprout-dogs round (village-dog-density * 0.04) [;;;;700 per km sq~28 per patch, 350 per sq km ~ 14 per patch
      set home-patch patch-here
      set shape "dog"
      set size 1.5
      set color orange
      set ip round (17 + random-normal 13 (13 / 4))
      set infected? false
      set infectious? false
      set susceptible? true
      set recovered? false
      set ddt 1
      ifelse (random 100 < prop-roam)
      [set rd? true]
      [set rd? false]
      ]
    ]
  ask patches with [pcolor = green] [
    if (random-float 100 < 50) [
      sprout-dogs 2 [
        set home-patch patch-here
      set shape "dog"
      set size 1.5
      set color orange
      set ip round (17 + random-normal 13 (13 / 4))
      set infected? false
      set infectious? false
      set susceptible? true
      set recovered? false
      set ddt 1
      ifelse (random 100 < prop-roam)
      [set rd? true]
      [set rd? false]
      ]
    ]
  ]

 set dog-population count dogs
 set fox-carcap round (count patches with [pcolor = black] / 16.6);;;;;;;;;;;;;~fox density 1.5 per km sq
   ask n-of (fox-carcap / 2) patches with [pcolor = black] [
     ifelse (count dogs-on neighbors = 0)
     [set pcolor yellow
       sprout-foxes 2 [
         set home-patch patch-here
         set shape "wolf 7"
         set color brown
         set susceptible? true
         set infected? false
         set infectious? false
         set immune? false
         set lid 0
         set scc 0
       ]
     ]
     [ask one-of neighbors [
         if (pcolor = black) and (count dogs-on neighbors = 0) [
           set pcolor yellow
           sprout-foxes 2 [
             set home-patch patch-here
             set shape "wolf 7"
             set color brown
             set susceptible? true
             set infected? false
             set infectious? false
             set immune? false
             set lid 0
             set scc 0
           ]
         ]
     ]
     ]
   ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to go
  if (ticks = 7301) [
    stop
  ]
  if count foxes < 1 [
    print "foxes extinct"
  ]
  if (ticks > 3649) [
    if (d = 0) [
      ask n-of (vaccdog * count dogs) dogs [
        if (susceptible?) [
          set susceptible? false
          set recovered? true
          set ddt 5000
        ]
      ]
      ask n-of (vaccfox * count foxes) foxes [
        if (susceptible?) [
          set susceptible? false
          set immune? true
          set cumsdcf (cumsdcf + sdc)
        ]
      ]
    ]
  ]

  set d (remainder (ticks) 365)
  set td (remainder (d) 30)


  if ((remainder (d) freq-cdv) = 0) [
    if (count dogs with [susceptible?] > 0) [
      ask n-of 1 dogs with [susceptible?] [
        set susceptible? false
        set cumsdc (cumsdc + sdc)
        set infected? true
        set color blue
        set ddt 4000
        set iddt 1
        set infdog0 (infdog0 + 1)
        ]
      ]
  ]
  if (d = 0) [
    set year (year + 1)
    set infdog0 0
    set infdog0m 0
    set inffox0 0
    set dog0 count dogs
    set fox0 count foxes
    set cumsdc 0
    set cumsdcf 0
    set famCDV 0
    ]
  if (d = 364) [
    set CDVdogincrate precision (infdog0 / (cumsdc / 30)) 2;;;;;;;;;;;;;;;;;annual CDV incidence rate in dogs
    if (cumsdcf > 0) [
      set CDVfoxincrate precision (inffox0 / (cumsdcf / 30)) 2;;;;;;;;;;;;;;annual CDV incidence rate in foxes
    ]
    ;file-open "CDVincidencerateannualdogs.txt"
    ;file-write CDVdogincrate
    ;file-close
    ;file-open "CDVincidencerateannualfoxes.txt"
    ;file-write CDVfoxincrate
    ;file-close
    ]
  ;if (td = 0) [
    ;set infdog0c infdog0
    ;set month (month + 1)
    ;if (month > 12) [
      ;set month 0
   ; ]
    ;]
  ;if (td = 29) [
    ;ifelse (month = 1)
    ;[set infdog0m infdog0]
    ;[set infdog0m (infdog0 - infdog0c)]
    ;print infdog0
    ;print infdog0m
    ;set pvd precision (count dogs with [ddt > 3999] / count dogs) 2
    ;file-open "CDVmonthwiseprevalence dogs.txt"
    ;file-write month file-write pvd
    ;file-close
    ;file-open "epizooticcurve.txt"
    ;file-write month file-write infdog0m
    ;file-close
  ;]



 if (ticks > 4013) [; for recording inc rate between 11-20 years use ticks>4013
    if (d = 364) [
    if (inffox0 > 0) [
      set spoeve (spoeve + 1)
    ]
    set yinfdog0 (yinfdog0 + infdog0)
    set ycumsdc (ycumsdc + cumsdc)
    set yinffox0 (yinffox0 + inffox0)
    set ycumsdcf (ycumsdcf + cumsdcf)
  ]
  ]
  if (ticks = 7300) [
    set CDVincratedog (yinfdog0 / (ycumsdc / 30))
    set CDVincratefox (yinffox0 / (ycumsdcf / 30))
    set probspo (spoeve / 10)
  ]
  set prosus (count dogs with [susceptible?] / count dogs)
  set prorec (count dogs with [recovered?] / count dogs)

  ask dogs [
    disease-risk
    dogs-roam-infect
    dogs-reproduce
    dogs-die
    ]
  ask dogs with [ddt = 4000] [
    dog-disease-progression
  ]
  ask dogs with [susceptible?] [
    if (d = 0) [
      set sdc 1
    ]
    if (d > 0) [
      set sdc (sdc + 1)
    ]
    if (d = 364) [
      set cumsdc (cumsdc + sdc)
    ]
  ]

  ask foxes [
    foxes-roam
    foxes-die
  ]

  ask foxes with [susceptible?] [
    if (d = 0) [
      set sdc 1
    ]
    if (d > 0) [
      set sdc (sdc + 1)
    ]
    if (d = 364) [
      set cumsdcf (cumsdcf + sdc)
      ]
  ]


  ask foxes with [infected?] [
    fox-disease-progression                       ;;;;;infectious-phase
  ]

  ask patches [
    update-fox-numbers
  ]

  let x (count foxes with [lid = 1])
  set inf-foxes (inf-foxes + x)

  if (count foxes > 0) [
    set pre (count foxes with [infected?] / count foxes)
  ]
  ;file-open "proprecdogs.txt"
  ;file-write precision (prorec) 2
  ;file-close
  tick
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



to disease-risk;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DOGS
  if (ddt < 3999) [
    set ddt ddt + 1
  ]

  if (ddt = 0) [
      set susceptible? true
      set sdc 1
      ifelse (random 100 < prop-roam)
      [set rd? true]
      [set rd? false]
    ]
end

to dogs-roam-infect;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DOGS
  pd
  rt random 360
  ifelse (not rd?)
  [fd round random-poisson .2]
  [fd round random-poisson 3]

  if (infectious?) [
    dog-infect-foxes
    dog-infect-dogs
  ]

  if (susceptible?) [
    dog-gets-infected
  ]

  pen-erase
  move-to home-patch

  if (infectious?) [
    dog-infect-foxes
    dog-infect-dogs
  ]

  if (susceptible?) [
    dog-gets-infected
  ]
end


to dog-infect-foxes
  ask foxes in-radius .5 [
    if (susceptible?) and (random-float 1 < dog-fox-transmissibility) [
      set susceptible? false
      set cumsdcf (cumsdcf + sdc)
      set infected? true
      set inffox0 (inffox0 + 1)
      set color red
      if (ticks > 3650) [
        set soe (soe + 1)
      ]
    ]
  ]
end

to dog-infect-dogs
  ask dogs in-radius .5[
      if (susceptible?) and (random-float 1 < dog-dog-transmissibility) [
        set susceptible? false
        set cumsdc (cumsdc + sdc)
        set infected? true
        set color blue
        set ddt 4000
        set iddt 1
        set infdog0 (infdog0 + 1)
        ]
      ]
end

to dog-gets-infected
  if any? dogs with [infectious?] in-radius .5[
      if (random-float 1 < dog-dog-transmissibility)[
        set susceptible? false
        set cumsdc (cumsdc + sdc)
        set infected? true
        set color blue
        set ddt 4000
        set iddt 1
        set infdog0 (infdog0 + 1)
        ]
      ]
end


to dog-disease-progression;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DOGS
  set iddt iddt + 1
  if (iddt = 7) [
    set infectious? true
    set color red
    ]
  if (iddt = 17) [
    if (random 100 < 25) [
      ;set cdm cdm + 1
      die
      ]
  ]
  if (iddt = ip) [
    set infected? false
    set infectious? false
    set recovered? true
    set susceptible? false
    set ddt 5000
    set color white
    set iddt 0
    ]

end

to dogs-reproduce
  if (d > 30) and (d < 150) [
    ifelse (m < (dog-population * 0.4))
    [let avbirths ((dog-population * 0.4) / 120)
      let abt (random-normal avbirths avbirths / 4)
      if (random 100 < abt) [
        hatch 1 [
          set home-patch patch-here
          set shape "dog"
          set size 1.5
          set color orange
          set ip round (17 + random-normal 13 (13 / 4))
          set infected? false
          set infectious? false
          set recovered? false
          set susceptible? false
          set ddt random -90                                          ;;;;;;;;;;;;;;;;;;;shouldnt it be -90 + random -90??????????????????????/
          ]
        set m m + 1
        ]
      ]
    [stop]
    ]
  if (d = 151) [
    set m 0
    ]

end


to dogs-die
  if (d = 364) [
    set s 0
  ]
  let mdog (1 / ((dog-population * 0.4) / 365))
  let dd (remainder (d) mdog)
  set ddd (ddd + dd)
  if (ddd > 1) [;if (dd > 1) [
    ifelse (s < (count dogs * 0.4))
    [if (random (count dogs) < 2)
      [set s s + 1
        if (susceptible?) [
          set cumsdc (cumsdc + sdc)
          ]
        die
        set ddd (ddd - 1)
      ]
    ]
    [stop]
  ]


end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to foxes-die
  let mfox 1 / ((fox-carcap * 0.2) / 365);;;;;;;;;;;;;;fox population turnover
  let dd round (remainder (d) mfox)
  if (dd = 1) [
    if (random (count foxes) < 1)[
      ifelse (infected?)
      [set famCDV (famCDV + 1)
        set cumscc cumscc + scc
        set cuminff cuminff + 1
        if (cuminff = 1) [
        set ro (cumscc / cuminff)
        die]
    ]
      [set cumsdcf (cumsdcf + sdc)
        die]
    ]
  ]

  ask patches with [pcolor = yellow] [
    let fhere count foxes-here
    if (fhere = 0) [
      set pcolor black
    ]
  ]
end

to update-fox-numbers
  if (d = 358) [
    let fr (fox-carcap - count foxes)
    ask n-of round (fr / 2) patches [
      if (pcolor = black) and (count dogs-on neighbors = 0)
      [set pcolor yellow
        sprout-foxes 2 [
          set home-patch patch-here
          set shape "wolf 7"
          set color brown
          set susceptible? true
          set infected? false
          set infectious? false
          set immune? false
          set lid 0
          set scc 0
          set sdc 1
        ]
      ]
    ]
  ]
end

to fox-disease-progression;;;;;;;;;;;;;;;;;;;;;infectious-phase foxes
  set lid (lid + 1)
  if (lid = 7) [
    set infectious? true
    set color green
  ]
  if (lid = 21) [
    set cumscc cumscc + scc
    set cuminff cuminff + 1
    if (cuminff = 1) [
      set ro (cumscc / cuminff)
    ]
    ifelse (random-float 100 < (immune-foxes))
    [set infected? false
      set infectious? false
      set immune? true
      set scc 0]
    [set famCDV (famCDV + 1)
      die]
  ]
end

to foxes-roam
  pd
  rt random 360 fd round (random-poisson 1.5)
  let ddogs dogs in-radius .5 with [infectious?]
  if (susceptible?) and (any? ddogs) [
    fox-gets-infected
    ]

  if (infectious?)[
    fox-infects-foxes
  ]

  pen-erase
  move-to home-patch
  if (susceptible?) and (any? ddogs) [
    fox-gets-infected
    ]

  if (infectious?)[
    fox-infects-foxes
  ]
end

to fox-gets-infected
  if (random-float 1 < dog-fox-transmissibility) [
      set susceptible? false
      set cumsdcf (cumsdcf + sdc)
      set infected? true
      set inffox0 (inffox0 + 1)
      set color red
      if (ticks > 3650) [
        set soe (soe + 1)
        ]
      ]
end

to fox-infects-foxes
  let inff count foxes in-radius .5 with [infected?]
    ask foxes in-radius .5 [
      if (susceptible?) and (random-float 1 < fox-fox-transmissibility)[
        set susceptible? false
        set cumsdcf (cumsdcf + sdc)
        set infected? true
        set inffox0 (inffox0 + 1)
        set color red
      ]
    ]
    let pif count foxes in-radius .5 with [infected?]
    set scc (scc + (pif - inff))
end












@#$#@#$#@
GRAPHICS-WINDOW
210
10
649
470
16
16
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
21
51
84
84
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
126
54
189
87
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
870
23
949
68
dog number
count dogs
0
1
11

PLOT
658
20
858
170
dog population
ticks
dog numbers
0.0
400.0
0.0
700.0
true
false
"plotxy ticks count dogs" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count dogs"

PLOT
660
197
860
347
SIR
ticks
no of dogs
0.0
1000.0
0.0
300.0
true
false
"plotxy ticks count dogs with [susceptible?]" ""
PENS
"default" 1.0 0 -14070903 true "" "plot count dogs with [recovered?]"
"pen-1" 1.0 0 -5298144 true "" "plot count dogs with [susceptible?]"

MONITOR
861
281
1041
326
proportion of susceptible dogs
prosus
2
1
11

MONITOR
862
227
1037
272
proportion of recovered dogs
prorec
2
1
11

SLIDER
27
306
199
339
prop-roam
prop-roam
0
50
25
5
1
NIL
HORIZONTAL

SLIDER
25
109
205
142
dog-dog-transmissibility
dog-dog-transmissibility
0
1
0.3
.1
1
NIL
HORIZONTAL

PLOT
662
373
862
523
CDV dog incidence rate
ticks
CDVincrate
0.0
3650.0
0.0
1.0
true
false
"plotxy ticks CDVdogincrate" ""
PENS
"default" 1.0 0 -5298144 true "" "plot CDVdogincrate"

SLIDER
25
150
203
183
dog-fox-transmissibility
dog-fox-transmissibility
0
1
0.2
.05
1
NIL
HORIZONTAL

SLIDER
24
406
196
439
immune-foxes
immune-foxes
0
10
0
1
1
NIL
HORIZONTAL

SLIDER
27
189
202
222
fox-fox-transmissibility
fox-fox-transmissibility
0
.5
0.3
.05
1
NIL
HORIZONTAL

MONITOR
1176
27
1269
72
infected foxes
inf-foxes
0
1
11

MONITOR
1089
25
1166
70
fox number
count foxes
0
1
11

PLOT
1087
83
1287
233
CDV in foxes
ticks
no_of_foxes
0.0
365.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -2674135 true "" "plot count foxes with [infected?]"

PLOT
1083
371
1283
521
CDV incidence rate foxes
years
CDVincratefoxes
0.0
3650.0
0.0
1.0
true
false
"plotxy ticks CDVfoxincrate" ""
PENS
"default" 1.0 0 -5298144 true "" "plot CDVfoxincrate"

SLIDER
26
269
198
302
village-dog-density
village-dog-density
350
840
700
10
1
NIL
HORIZONTAL

MONITOR
864
373
959
418
NIL
CDVincratedog
2
1
11

MONITOR
990
372
1083
417
NIL
CDVincratefox
2
1
11

MONITOR
918
440
1037
485
spillover probability
probspo
2
1
11

MONITOR
927
500
1027
545
spillover events
soe
0
1
11

SLIDER
26
230
198
263
freq-cdv
freq-cdv
0
360
60
30
1
NIL
HORIZONTAL

SLIDER
22
447
194
480
vaccdog
vaccdog
0
1
0
.25
1
NIL
HORIZONTAL

SLIDER
22
484
194
517
vaccfox
vaccfox
0
1
0
.25
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

The purpose of this model is to explore the transmission dynamics of canine distemper virus (CDV) in a two-host system, comprised of an abundant dog population and a relatively low density Indian fox population in central India.

## HOW IT WORKS

Each patch represents a habitat type, viz. fallow land-grassland complex, farmlands and human habitations. Foxes occur on fallow land-grassland complex, while dogs are associated with villages and farmlands. Dogs and foxes are characterized by the identity of the home patch they occupy, and their disease status (susceptible, infected, and infectious). Dogs are also characterized by their roaming tendencies- ‘roamers’ cover larger area during their daily excursions than ‘non-roamers.

CDV is endemic in dogs, dogs can recover from CDV infection and become immune for life. Foxes are susceptible to CDV. but do not recover once infected, and none of the foxes have immunity against CDV.

The time step for this model is 1 day, and simulations were run over 20 years.
Infection status of individuals (dogs and foxes) is followed throughout the model run. Movements, interactions and population dynamics of dogs and foxes are simulated using
the following processes: (i) dogs roam-infect: every day, dogs return to their home-patch after visiting a random patch in their home-range, possibly getting infected or infecting another dog or fox; (ii) foxes roam-infect: every day, foxes return to their home-patch after visiting a random patch in their home-range, possibly getting infected or infecting another fox; (iii) dogs recurrent-CDV-introduction: CDV is introduced periodically in the dog population by randomly changing the status of one susceptible dog to ‘exposed’; (iv) dog disease-progression: exposed dog sheds CDV virus (becomes infectious) after an
incubation period, and then dies or recovers (becomes immune to CDV); (v) fox disease-progression: all foxes exposed to CDV become infectious after the incubation period, and then die; (vi) dogs reproduce (during the breeding season); (vii) dog disease-risk: pups enter the susceptible class from 3 to 6 months of age,and are also assigned roamer/non-roamer status; (viii) dogs die: dogs also die due to other causes throughout the year, (ix) foxes die: foxes also die due to other causes throughout the year; (x) update fox-numbers: In the last week of every year, foxes that
have died during the year are replaced so as to maintain the fox population at carrying capacity.

## HOW TO USE IT

1) Set the density of village dogs using the 'village-dog-density' slider. Values between 350 and 840 dogs per square kilometer can be chosen. Belsare & Gompper (2013) have documented a median village dog density of 719 dogs per square kilometer in and around a protected grassland in central India.
2) Set the proportion of 'roamer' dogs in the population using the 'prop-roam' slider. Values between 0 and 50 can be chosen. Based on data from photographic surveys of village
dogs undertaken around a protected grassland in central India, around 20–25% of the dogs were ‘roamers’ with average daily excursions of around 1.2 km (Belsare,unpublished data).
3) The frequency of CDV introduction in the dog population is set to 60 using the 'freq-cdv' slider (CDV introduced once every two months - status of one randomly selected susceptible dog is changed to infected).
4) The transmissibility sliders ('dog-dog','dog-fox' and 'fox-fox') are set at 0.3, 0.2 and 0.25 respectively. There are no empirical estimates for the transmissibility
parameter for CDV in dogs and foxes, but CDV is a highly contagious disease of domestic and wild carnivores, and values >0.2 indicate high rates of transmissibility (Craft et al.,2009), hence we recommend these high values. We assume that the disease-causing
contacts between foxes and dogs would include indirect interactions like foxes investigating dog scat and urine, or sequentialfeeding events, as dogs are an important cause of Indian fox mortality and are avoided by foxes (Vanak et al., 2009).
5) The remaining three sliders ('immune-foxes','vaccdog','vaccfox') can be manipulated to compare alternative assumptions and management strategies.


## THINGS TO NOTICE

CDV incidence rate in dogs from years 11 to 20 (10 year period) of the model run is noted in the monitor 'CDVincratedog'. Incidence rate is defined as the number of new cases of disease occurring in a population over a period divided by the sum of animal-years at risk for each individual in the population for that period, and indicates how fast a disease spreads in a population.
The other output parameter of interest is the number of CDV transmission events between dogs (the reservoir host) and foxes in a period of 10 years. Total number of CDV cases occurring in the fox population due to direct transmission from dogs from years 11 to 20 are noted in the monitor 'spillover events'.


## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dog
false
0
Polygon -7500403 true true 300 165 300 195 270 210 183 204 180 240 165 270 165 300 120 300 0 240 45 165 75 90 75 45 105 15 135 45 165 45 180 15 225 15 255 30 225 30 210 60 225 90 225 105
Polygon -16777216 true false 0 240 120 300 165 300 165 285 120 285 10 221
Line -16777216 false 210 60 180 45
Line -16777216 false 90 45 90 90
Line -16777216 false 90 90 105 105
Line -16777216 false 105 105 135 60
Line -16777216 false 90 45 135 60
Line -16777216 false 135 60 135 45
Line -16777216 false 181 203 151 203
Line -16777216 false 150 201 105 171
Circle -16777216 true false 171 88 34
Circle -16777216 false false 261 162 30

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

wolf 7
false
0
Circle -16777216 true false 183 138 24
Circle -16777216 true false 93 138 24
Polygon -7500403 true true 30 105 30 150 90 195 120 270 120 300 180 300 180 270 210 195 270 150 270 105 210 75 90 75
Polygon -7500403 true true 255 105 285 60 255 0 210 45 195 75
Polygon -7500403 true true 45 105 15 60 45 0 90 45 105 75
Circle -16777216 true false 90 135 30
Circle -16777216 true false 180 135 30
Polygon -16777216 true false 120 300 150 255 180 300

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="model c" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>avgCDVdogincrate</metric>
    <metric>avgCDVfoxincrate</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="noofmodelruns" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>avgCDVdogincrate</metric>
    <metric>avgCDVfoxincrate</metric>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="noofmodelruns_mostrecent20130802" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100runs_10yearIR_20130803" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="aaaaa" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>probspo</metric>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130804_50RUNS" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130805_baseline&amp;villagedogpopsa" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
      <value value="840"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130805_sa_proprd" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130805_sa_freq" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130805_sa_ddt" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130805_sa_dft" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.24"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_vaccdog" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vaccdog">
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_roamerdog_20130805" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vaccdog">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="630"/>
      <value value="560"/>
      <value value="350"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_REDROAMERDOGS_20130806" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CDVincratedog</metric>
    <metric>CDVincratefox</metric>
    <metric>probspo</metric>
    <metric>soe</metric>
    <enumeratedValueSet variable="prop-roam">
      <value value="22.5"/>
      <value value="20"/>
      <value value="12.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vaccdog">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="model_runs_1000" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>soe</metric>
    <enumeratedValueSet variable="dog-dog-transmissibility">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immune-foxes">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vaccdog">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq-cdv">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-dog-density">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fox-fox-transmissibility">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vaccfox">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dog-fox-transmissibility">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-roam">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
